pub struct RuntimeOrigin {
pub caller: OriginCaller,
/* private fields */
}Expand description
The runtime origin type representing the origin of a call.
Origin is always created with the base filter configured in frame_system::Config::BaseCallFilter.
Fields
caller: OriginCallerImplementations
Sourceimpl RuntimeOrigin
impl RuntimeOrigin
Sourcepub fn none() -> Self
pub fn none() -> Self
Create with system none origin and frame_system::Config::BaseCallFilter.
Sourcepub fn root() -> Self
pub fn root() -> Self
Create with system root origin and frame_system::Config::BaseCallFilter.